@@ -3,9 +3,10 @@ use strict;
 use warnings;
 use utf8;
 use FindBin;
+use Test::More ();
 
 use base 'Exporter';
-our @EXPORT = qw/capture init $OUT $ERR/;
+our @EXPORT = qw/capture init $OUT $ERR is_valid_output/;
 
 our $OUT;
 our $ERR;
@@ -30,4 +31,10 @@ sub capture(&) {
     untie *STDOUT;
 }
 
+sub is_valid_output {
+    my ($out, $out_expects, $test_name) = @_;
+
+    Test::More::is_deeply([sort split /\n/, $out], [sort @$out_expects], $test_name);
+}
+
 1;
